#[non_exhaustive]pub enum CardAvailablePayoutMethods {
Instant,
Standard,
Unknown(String),
}Expand description
A set of available payout methods for this card.
Only values from this set should be passed as the method when creating a payout.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Instant
Standard
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations