#[non_exhaustive]pub enum CreditNoteLineItemType {
CustomLineItem,
InvoiceLineItem,
Unknown(String),
}Expand description
The type of the credit note line item, one of invoice_line_item or custom_line_item.
When the type is invoice_line_item there is an additional invoice_line_item property on the resource the value of which is the id of the credited line item on the invoice.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CustomLineItem
InvoiceLineItem
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations