#[non_exhaustive]pub enum InvoicePaymentMethodOptionsMandateOptionsUpiAmountType {
Fixed,
Maximum,
Unknown(String),
}Expand description
One of fixed or maximum.
If fixed, the amount param refers to the exact amount to be charged in future payments.
If maximum, the amount charged can be up to the value passed for the amount param.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fixed
Maximum
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations