#[non_exhaustive]pub enum PaymentMethodDetailsPaymentRecordSofortPreferredLanguage {
De,
En,
Es,
Fr,
It,
Nl,
Pl,
Unknown(String),
}Expand description
Preferred language of the SOFORT authorization page that the customer is redirected to.
Can be one of de, en, es, fr, it, nl, or pl.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
De
En
Es
Fr
It
Nl
Pl
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations