#[non_exhaustive]pub enum SetupAttemptPaymentMethodDetailsCardWalletType {
ApplePay,
GooglePay,
Link,
Unknown(String),
}Expand description
The type of the card wallet, one of apple_pay, google_pay, or link.
An additional hash is included on the Wallet subhash with a name matching this value.
It contains additional information specific to the card wallet type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ApplePay
GooglePay
Link
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations