#[non_exhaustive]pub enum SetupIntentPaymentMethodOptionsMandateOptionsPaytoAmountType {
Fixed,
Maximum,
Unknown(String),
}Expand description
The type of amount that will be collected.
The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively.
Defaults to maximum.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fixed
Maximum
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations