#[non_exhaustive]pub enum TaxRateRateType {
FlatAmount,
Percentage,
Unknown(String),
}Expand description
Indicates the type of tax rate applied to the taxable amount.
This value can be null when no tax applies to the location.
This field is only present for TaxRates created by Stripe Tax.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FlatAmount
Percentage
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations