AccountCapabilityRequirements

Struct AccountCapabilityRequirements 

pub struct AccountCapabilityRequirements {
    pub alternatives: Option<Vec<AccountRequirementsAlternative>>,
    pub current_deadline: Option<Timestamp>,
    pub currently_due: Vec<String>,
    pub disabled_reason: Option<AccountCapabilityRequirementsDisabledReason>,
    pub errors: Vec<AccountRequirementsError>,
    pub eventually_due: Vec<String>,
    pub past_due: Vec<String>,
    pub pending_verification: Vec<String>,
}

Fields

alternatives: Option<Vec<AccountRequirementsAlternative>>

Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the same original_fields_due. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providing original_fields_due again also serves as a pathway for attempting to resolve the fields.

current_deadline: Option<Timestamp>

The date by which all required account information must be both submitted and verified. This includes fields listed in currently_due as well as those in pending_verification. If any required information is missing or unverified by this date, the account may be disabled. Note that current_deadline may change if additional currently_due requirements are requested.

currently_due: Vec<String>

Fields that need to be resolved to keep the capability enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the capability is disabled.

disabled_reason: Option<AccountCapabilityRequirementsDisabledReason>

Description of why the capability is disabled. Learn more about handling verification issues.

errors: Vec<AccountRequirementsError>

Details about validation and verification failures for due requirements that must be resolved.

eventually_due: Vec<String>

Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and current_deadline becomes set.

past_due: Vec<String>

Fields that haven’t been resolved by current_deadline. These fields need to be resolved to enable the capability on the account.

pending_verification: Vec<String>

Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.