AccountUnificationAccountController

Struct AccountUnificationAccountController 

pub struct AccountUnificationAccountController {
    pub fees: Option<AccountUnificationAccountControllerFees>,
    pub is_controller: Option<bool>,
    pub losses: Option<AccountUnificationAccountControllerLosses>,
    pub requirement_collection: Option<AccountUnificationAccountControllerRequirementCollection>,
    pub stripe_dashboard: Option<AccountUnificationAccountControllerStripeDashboard>,
    pub type_: AccountUnificationAccountControllerType,
}

Fields

fees: Option<AccountUnificationAccountControllerFees>is_controller: Option<bool>

true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.

losses: Option<AccountUnificationAccountControllerLosses>requirement_collection: Option<AccountUnificationAccountControllerRequirementCollection>

A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.

stripe_dashboard: Option<AccountUnificationAccountControllerStripeDashboard>type_: AccountUnificationAccountControllerType

The controller type. Can be application, if a Connect application controls the account, or account, if the account controls itself.