pub struct CustomerBalanceCustomerBalanceSettings {
pub reconciliation_mode: CustomerBalanceCustomerBalanceSettingsReconciliationMode,
pub using_merchant_default: bool,
}Fields
reconciliation_mode: CustomerBalanceCustomerBalanceSettingsReconciliationModeThe configuration for how funds that land in the customer cash balance are reconciled.
using_merchant_default: boolA flag to indicate if reconciliation mode returned is the user’s default or is specific to this customer cash balance.