InvoiceLineItem

Struct InvoiceLineItem 

pub struct InvoiceLineItem {
Show 19 fields pub amount: i64, pub currency: Currency, pub description: Option<String>, pub discount_amounts: Option<Vec<DiscountsResourceDiscountAmount>>, pub discountable: bool, pub discounts: Vec<Expandable<Discount>>, pub id: InvoiceLineItemId, pub invoice: Option<String>, pub livemode: bool, pub metadata: HashMap<String, String>, pub parent: Option<BillingBillResourceInvoicingLinesParentsInvoiceLineItemParent>, pub period: InvoiceLineItemPeriod, pub pretax_credit_amounts: Option<Vec<InvoicesResourcePretaxCreditAmount>>, pub pricing: Option<BillingBillResourceInvoicingPricingPricing>, pub quantity: Option<u64>, pub quantity_decimal: Option<String>, pub subscription: Option<Expandable<Subscription>>, pub subtotal: i64, pub taxes: Option<Vec<BillingBillResourceInvoicingTaxesTax>>,
}
Invoice Line Items represent the individual lines within an invoice and only exist within the context of an invoice.

Each line item is backed by either an invoice item or a subscription item.

Fields

amount: i64

The amount, in cents (or local equivalent).

currency: Currency

Three-letter ISO currency code, in lowercase. Must be a supported currency.

description: Option<String>

An arbitrary string attached to the object. Often useful for displaying to users.

discount_amounts: Option<Vec<DiscountsResourceDiscountAmount>>

The amount of discount calculated per discount for this line item.

discountable: bool

If true, discounts will apply to this line item. Always false for prorations.

discounts: Vec<Expandable<Discount>>

The discounts applied to the invoice line item. Line item discounts are applied before invoice discounts. Use expand[]=discounts to expand each discount.

id: InvoiceLineItemId

Unique identifier for the object.

invoice: Option<String>

The ID of the invoice that contains this line item.

livemode: bool

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.

metadata: HashMap<String, String>

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Note that for line items with type=subscription, metadata reflects the current metadata from the subscription associated with the line item, unless the invoice line was directly updated with different metadata after creation.

parent: Option<BillingBillResourceInvoicingLinesParentsInvoiceLineItemParent>

The parent that generated this line item.

period: InvoiceLineItemPeriodpretax_credit_amounts: Option<Vec<InvoicesResourcePretaxCreditAmount>>

Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this line item.

pricing: Option<BillingBillResourceInvoicingPricingPricing>

The pricing information of the line item.

quantity: Option<u64>

Quantity of units for the invoice line item in integer format, with any decimal precision truncated. For the line item’s full-precision decimal quantity, use quantity_decimal. This field will be deprecated in favor of quantity_decimal in a future version. If the line item is a proration or subscription, the quantity of the subscription that the proration was computed for.

quantity_decimal: Option<String>

Non-negative decimal with at most 12 decimal places. The quantity of units for the line item.

subscription: Option<Expandable<Subscription>>subtotal: i64

The subtotal of the line item, in cents (or local equivalent), before any discounts or taxes.

taxes: Option<Vec<BillingBillResourceInvoicingTaxesTax>>

The tax information of the line item.