pub struct InvoiceSettingCheckoutRenderingOptions {
pub amount_tax_display: Option<String>,
pub template: Option<String>,
}Fields
amount_tax_display: Option<String>How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
template: Option<String>ID of the invoice rendering template to be used for the generated invoice.