pub struct InvoiceSettingCustomerRenderingOptions {
pub amount_tax_display: Option<String>,
pub template: Option<String>,
}Fields
amount_tax_display: Option<String>How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
template: Option<String>ID of the invoice rendering template to be used for this customer’s invoices. If set, the template will be used on all invoices for this customer unless a template is set directly on the invoice.