pub struct InvoiceSettingSubscriptionSchedulePhaseSetting {
pub account_tax_ids: Option<Vec<Expandable<TaxId>>>,
pub custom_fields: Option<Vec<InvoiceSettingCustomField>>,
pub days_until_due: Option<u32>,
pub description: Option<String>,
pub footer: Option<String>,
pub issuer: Option<ConnectAccountReference>,
}Fields
account_tax_ids: Option<Vec<Expandable<TaxId>>>The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
custom_fields: Option<Vec<InvoiceSettingCustomField>>A list of up to 4 custom fields to be displayed on the invoice.
days_until_due: Option<u32>Number of days within which a customer must pay invoices generated by this subscription schedule.
This value will be null for subscription schedules where billing=charge_automatically.
description: Option<String>An arbitrary string attached to the object. Often useful for displaying to users.
Footer to be displayed on the invoice.
issuer: Option<ConnectAccountReference>The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.