pub struct InvoiceSettingSubscriptionScheduleSetting {
pub account_tax_ids: Option<Vec<Expandable<TaxId>>>,
pub days_until_due: Option<u32>,
pub issuer: ConnectAccountReference,
}Fields
account_tax_ids: Option<Vec<Expandable<TaxId>>>The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
days_until_due: Option<u32>Number of days within which a customer must pay invoices generated by this subscription schedule.
This value will be null for subscription schedules where billing=charge_automatically.
issuer: ConnectAccountReferenceTrait Implementations
Sourceimpl Clone for InvoiceSettingSubscriptionScheduleSetting
impl Clone for InvoiceSettingSubscriptionScheduleSetting
Sourcefn clone(&self) -> InvoiceSettingSubscriptionScheduleSetting
fn clone(&self) -> InvoiceSettingSubscriptionScheduleSetting
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl FromValueOpt for InvoiceSettingSubscriptionScheduleSetting
impl FromValueOpt for InvoiceSettingSubscriptionScheduleSetting
fn from_value(v: Value) -> Option<Self>