InvoicesPaymentMethodOptions

Struct InvoicesPaymentMethodOptions 

pub struct InvoicesPaymentMethodOptions {
    pub acss_debit: Option<InvoicePaymentMethodOptionsAcssDebit>,
    pub bancontact: Option<InvoicePaymentMethodOptionsBancontact>,
    pub card: Option<InvoicePaymentMethodOptionsCard>,
    pub customer_balance: Option<InvoicePaymentMethodOptionsCustomerBalance>,
    pub konbini: Option<InvoicePaymentMethodOptionsKonbini>,
    pub payto: Option<InvoicePaymentMethodOptionsPayto>,
    pub pix: Option<InvoicePaymentMethodOptionsPix>,
    pub sepa_debit: Option<InvoicePaymentMethodOptionsSepaDebit>,
    pub upi: Option<InvoicePaymentMethodOptionsUpi>,
    pub us_bank_account: Option<InvoicePaymentMethodOptionsUsBankAccount>,
}

Fields

acss_debit: Option<InvoicePaymentMethodOptionsAcssDebit>

If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.

bancontact: Option<InvoicePaymentMethodOptionsBancontact>

If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.

card: Option<InvoicePaymentMethodOptionsCard>

If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.

customer_balance: Option<InvoicePaymentMethodOptionsCustomerBalance>

If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.

konbini: Option<InvoicePaymentMethodOptionsKonbini>

If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.

payto: Option<InvoicePaymentMethodOptionsPayto>

If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.

pix: Option<InvoicePaymentMethodOptionsPix>

If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.

sepa_debit: Option<InvoicePaymentMethodOptionsSepaDebit>

If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.

upi: Option<InvoicePaymentMethodOptionsUpi>

If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.

us_bank_account: Option<InvoicePaymentMethodOptionsUsBankAccount>

If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.