IssuingAuthorizationMerchantData

Struct IssuingAuthorizationMerchantData 

pub struct IssuingAuthorizationMerchantData {
    pub category: String,
    pub category_code: String,
    pub city: Option<String>,
    pub country: Option<String>,
    pub name: Option<String>,
    pub network_id: String,
    pub postal_code: Option<String>,
    pub state: Option<String>,
    pub tax_id: Option<String>,
    pub terminal_id: Option<String>,
    pub url: Option<String>,
}

Fields

category: String

A categorization of the seller’s type of business. See our merchant categories guide for a list of possible values.

category_code: String

The merchant category code for the seller’s business

city: Option<String>

City where the seller is located

country: Option<String>

Country where the seller is located

name: Option<String>

Name of the seller

network_id: String

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.

postal_code: Option<String>

Postal code where the seller is located

state: Option<String>

State where the seller is located

tax_id: Option<String>

The seller’s tax identification number. Currently populated for French merchants only.

terminal_id: Option<String>

An ID assigned by the seller to the location of the sale.

url: Option<String>

URL provided by the merchant on a 3DS request