pub struct IssuingAuthorizationNetworkData {
pub acquiring_institution_id: Option<String>,
pub system_trace_audit_number: Option<String>,
pub transaction_id: Option<String>,
}Fields
acquiring_institution_id: Option<String>Identifier assigned to the acquirer by the card network.
Sometimes this value is not provided by the network; in this case, the value will be null.
system_trace_audit_number: Option<String>The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer.
Prefer network_data.transaction_id if present, unless you have special requirements.
transaction_id: Option<String>Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.