pub struct IssuingCardSpendingLimit {
pub amount: i64,
pub categories: Option<Vec<IssuingCardSpendingLimitCategories>>,
pub interval: IssuingCardSpendingLimitInterval,
}Fields
amount: i64Maximum amount allowed to spend per interval. This amount is in the card’s currency and in the smallest currency unit.
categories: Option<Vec<IssuingCardSpendingLimitCategories>>Array of strings containing categories this limit applies to. Omitting this field will apply the limit to all categories.
interval: IssuingCardSpendingLimitIntervalInterval (or event) to which the amount applies.