IssuingCardholder

Struct IssuingCardholder 

pub struct IssuingCardholder {
Show 15 fields pub billing: IssuingCardholderAddress, pub company: Option<IssuingCardholderCompany>, pub created: Timestamp, pub email: Option<String>, pub id: IssuingCardholderId, pub individual: Option<IssuingCardholderIndividual>, pub livemode: bool, pub metadata: HashMap<String, String>, pub name: String, pub phone_number: Option<String>, pub preferred_locales: Option<Vec<IssuingCardholderPreferredLocales>>, pub requirements: IssuingCardholderRequirements, pub spending_controls: Option<IssuingCardholderAuthorizationControls>, pub status: IssuingCardholderStatus, pub type_: IssuingCardholderType,
}
An Issuing Cardholder object represents an individual or business entity who is issued cards.

Related guide: How to create a cardholder.

For more details see <https://stripe.com/docs/api/issuing/cardholders/object>.

Fields

billing: IssuingCardholderAddresscompany: Option<IssuingCardholderCompany>

Additional information about a company cardholder.

created: Timestamp

Time at which the object was created. Measured in seconds since the Unix epoch.

email: Option<String>

The cardholder’s email address.

id: IssuingCardholderId

Unique identifier for the object.

individual: Option<IssuingCardholderIndividual>

Additional information about an individual cardholder.

livemode: bool

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.

metadata: HashMap<String, String>

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.

name: String

The cardholder’s name. This will be printed on cards issued to them.

phone_number: Option<String>

The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.

preferred_locales: Option<Vec<IssuingCardholderPreferredLocales>>

The cardholder’s preferred locales (languages), ordered by preference. Locales can be da, de, en, es, fr, it, pl, or sv. This changes the language of the 3D Secure flow and one-time password messages sent to the cardholder.

requirements: IssuingCardholderRequirementsspending_controls: Option<IssuingCardholderAuthorizationControls>

Rules that control spending across this cardholder’s cards. Refer to our documentation for more details.

status: IssuingCardholderStatus

Specifies whether to permit authorizations on this cardholder’s cards.

type_: IssuingCardholderType

One of individual or company. See Choose a cardholder type for more details.