pub struct IssuingCardholderAuthorizationControls {
pub allowed_card_presences: Option<Vec<IssuingCardholderAuthorizationControlsAllowedCardPresences>>,
pub allowed_categories: Option<Vec<IssuingCardholderAuthorizationControlsAllowedCategories>>,
pub allowed_merchant_countries: Option<Vec<String>>,
pub blocked_card_presences: Option<Vec<IssuingCardholderAuthorizationControlsBlockedCardPresences>>,
pub blocked_categories: Option<Vec<IssuingCardholderAuthorizationControlsBlockedCategories>>,
pub blocked_merchant_countries: Option<Vec<String>>,
pub spending_limits: Option<Vec<IssuingCardholderSpendingLimit>>,
pub spending_limits_currency: Option<Currency>,
}Fields
allowed_card_presences: Option<Vec<IssuingCardholderAuthorizationControlsAllowedCardPresences>>Array of card presence statuses from which authorizations will be allowed.
Possible options are present, not_present.
All other statuses will be blocked.
Cannot be set with blocked_card_presences.
Provide an empty value to unset this control.
allowed_categories: Option<Vec<IssuingCardholderAuthorizationControlsAllowedCategories>>Array of strings containing categories of authorizations to allow.
All other categories will be blocked.
Cannot be set with blocked_categories.
allowed_merchant_countries: Option<Vec<String>>Array of strings containing representing countries from which authorizations will be allowed.
Authorizations from merchants in all other countries will be declined.
Country codes should be ISO 3166 alpha-2 country codes (e.g.
US).
Cannot be set with blocked_merchant_countries.
Provide an empty value to unset this control.
blocked_card_presences: Option<Vec<IssuingCardholderAuthorizationControlsBlockedCardPresences>>Array of card presence statuses from which authorizations will be declined.
Possible options are present, not_present.
Cannot be set with allowed_card_presences.
Provide an empty value to unset this control.
blocked_categories: Option<Vec<IssuingCardholderAuthorizationControlsBlockedCategories>>Array of strings containing categories of authorizations to decline.
All other categories will be allowed.
Cannot be set with allowed_categories.
blocked_merchant_countries: Option<Vec<String>>Array of strings containing representing countries from which authorizations will be declined.
Country codes should be ISO 3166 alpha-2 country codes (e.g.
US).
Cannot be set with allowed_merchant_countries.
Provide an empty value to unset this control.
spending_limits: Option<Vec<IssuingCardholderSpendingLimit>>Limit spending with amount-based rules that apply across this cardholder’s cards.
spending_limits_currency: Option<Currency>Currency of the amounts within spending_limits.