pub struct IssuingDisputeMerchandiseNotAsDescribedEvidence {
pub additional_documentation: Option<Expandable<File>>,
pub explanation: Option<String>,
pub received_at: Option<Timestamp>,
pub return_description: Option<String>,
pub return_status: Option<IssuingDisputeMerchandiseNotAsDescribedEvidenceReturnStatus>,
pub returned_at: Option<Timestamp>,
}Fields
additional_documentation: Option<Expandable<File>>(ID of a file upload) Additional documentation supporting the dispute.
explanation: Option<String>Explanation of why the cardholder is disputing this transaction.
received_at: Option<Timestamp>Date when the product was received.
return_description: Option<String>Description of the cardholder’s attempt to return the product.
return_status: Option<IssuingDisputeMerchandiseNotAsDescribedEvidenceReturnStatus>Result of cardholder’s attempt to return the product.
returned_at: Option<Timestamp>Date when the product was returned or attempted to be returned.