IssuingNetworkTokenAddress

Struct IssuingNetworkTokenAddress 

pub struct IssuingNetworkTokenAddress {
    pub line1: String,
    pub postal_code: String,
}

Fields

line1: String

The street address of the cardholder tokenizing the card.

postal_code: String

The postal code of the cardholder tokenizing the card.