pub struct IssuingNetworkTokenMastercard {
pub card_reference_id: Option<String>,
pub token_reference_id: String,
pub token_requestor_id: String,
pub token_requestor_name: Option<String>,
}Fields
card_reference_id: Option<String>A unique reference ID from MasterCard to represent the card account number.
token_reference_id: StringThe network-unique identifier for the token.
token_requestor_id: StringThe ID of the entity requesting tokenization, specific to MasterCard.
token_requestor_name: Option<String>The name of the entity requesting tokenization, if known. This is directly provided from MasterCard.