IssuingNetworkTokenNetworkData

Struct IssuingNetworkTokenNetworkData 

pub struct IssuingNetworkTokenNetworkData {
    pub device: Option<IssuingNetworkTokenDevice>,
    pub mastercard: Option<IssuingNetworkTokenMastercard>,
    pub type_: IssuingNetworkTokenNetworkDataType,
    pub visa: Option<IssuingNetworkTokenVisa>,
    pub wallet_provider: Option<IssuingNetworkTokenWalletProvider>,
}

Fields

device: Option<IssuingNetworkTokenDevice>mastercard: Option<IssuingNetworkTokenMastercard>type_: IssuingNetworkTokenNetworkDataType

The network that the token is associated with. An additional hash is included with a name matching this value, containing tokenization data specific to the card network.

visa: Option<IssuingNetworkTokenVisa>wallet_provider: Option<IssuingNetworkTokenWalletProvider>