IssuingNetworkTokenVisa

Struct IssuingNetworkTokenVisa 

pub struct IssuingNetworkTokenVisa {
    pub card_reference_id: Option<String>,
    pub token_reference_id: String,
    pub token_requestor_id: String,
    pub token_risk_score: Option<String>,
}

Fields

card_reference_id: Option<String>

A unique reference ID from Visa to represent the card account number.

token_reference_id: String

The network-unique identifier for the token.

token_requestor_id: String

The ID of the entity requesting tokenization, specific to Visa.

token_risk_score: Option<String>

Degree of risk associated with the token between 01 and 99, with higher number indicating higher risk. A 00 value indicates the token was not scored by Visa.