IssuingPersonalizationDesignPreferences

Struct IssuingPersonalizationDesignPreferences 

pub struct IssuingPersonalizationDesignPreferences {
    pub is_default: bool,
    pub is_platform_default: Option<bool>,
}

Fields

is_default: bool

Whether we use this personalization design to create cards when one isn’t specified. A connected account uses the Connect platform’s default design if no personalization design is set as the default design.

is_platform_default: Option<bool>

Whether this personalization design is used to create cards when one is not specified and a default for this connected account does not exist.