IssuingPhysicalBundle

Struct IssuingPhysicalBundle 

pub struct IssuingPhysicalBundle {
    pub features: IssuingPhysicalBundleFeatures,
    pub id: IssuingPhysicalBundleId,
    pub livemode: bool,
    pub name: String,
    pub status: IssuingPhysicalBundleStatus,
    pub type_: IssuingPhysicalBundleType,
}
A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.

Fields

features: IssuingPhysicalBundleFeaturesid: IssuingPhysicalBundleId

Unique identifier for the object.

livemode: bool

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.

name: String

Friendly display name.

status: IssuingPhysicalBundleStatus

Whether this physical bundle can be used to create cards.

type_: IssuingPhysicalBundleType

Whether this physical bundle is a standard Stripe offering or custom-made for you.