IssuingTransactionFleetCardholderPromptData

Struct IssuingTransactionFleetCardholderPromptData 

pub struct IssuingTransactionFleetCardholderPromptData {
    pub driver_id: Option<String>,
    pub odometer: Option<i64>,
    pub unspecified_id: Option<String>,
    pub user_id: Option<String>,
    pub vehicle_number: Option<String>,
}

Fields

driver_id: Option<String>

Driver ID.

odometer: Option<i64>

Odometer reading.

unspecified_id: Option<String>

An alphanumeric ID. This field is used when a vehicle ID, driver ID, or generic ID is entered by the cardholder, but the merchant or card network did not specify the prompt type.

user_id: Option<String>

User ID.

vehicle_number: Option<String>

Vehicle number.