pub struct IssuingTransactionFuelData {
pub industry_product_code: Option<String>,
pub quantity_decimal: Option<String>,
pub type_: String,
pub unit: String,
pub unit_cost_decimal: String,
}Fields
industry_product_code: Option<String>Conexxus Payment System Product Code identifying the primary fuel product purchased.
quantity_decimal: Option<String>The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
type_: StringThe type of fuel that was purchased.
One of diesel, unleaded_plus, unleaded_regular, unleaded_super, or other.
unit: StringThe units for quantity_decimal.
One of charging_minute, imperial_gallon, kilogram, kilowatt_hour, liter, pound, us_gallon, or other.
unit_cost_decimal: StringThe cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.