IssuingTransactionTreasury

Struct IssuingTransactionTreasury 

pub struct IssuingTransactionTreasury {
    pub received_credit: Option<String>,
    pub received_debit: Option<String>,
}

Fields

received_credit: Option<String>

The Treasury ReceivedCredit representing this Issuing transaction if it is a refund.

received_debit: Option<String>

The Treasury ReceivedDebit representing this Issuing transaction if it is a capture.