pub struct LegalEntityDirectorshipDeclaration {
pub date: Option<Timestamp>,
pub ip: Option<String>,
pub user_agent: Option<String>,
}Fields
date: Option<Timestamp>The Unix timestamp marking when the directorship declaration attestation was made.
ip: Option<String>The IP address from which the directorship declaration attestation was made.
user_agent: Option<String>The user-agent string from the browser where the directorship declaration attestation was made.