LegalEntityUboDeclaration

Struct LegalEntityUboDeclaration 

pub struct LegalEntityUboDeclaration {
    pub date: Option<Timestamp>,
    pub ip: Option<String>,
    pub user_agent: Option<String>,
}

Fields

date: Option<Timestamp>

The Unix timestamp marking when the beneficial owner attestation was made.

ip: Option<String>

The IP address from which the beneficial owner attestation was made.

user_agent: Option<String>

The user-agent string from the browser where the beneficial owner attestation was made.