pub struct LineItemsTaxAmount {
pub amount: i64,
pub rate: TaxRate,
pub taxability_reason: Option<LineItemsTaxAmountTaxabilityReason>,
pub taxable_amount: Option<i64>,
}Fields
amount: i64Amount of tax applied for this rate.
rate: TaxRatetaxability_reason: Option<LineItemsTaxAmountTaxabilityReason>The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
taxable_amount: Option<i64>The amount on which tax is calculated, in cents (or local equivalent).