MandatePix

Struct MandatePix 

pub struct MandatePix {
    pub amount_includes_iof: Option<MandatePixAmountIncludesIof>,
    pub amount_type: Option<MandatePixAmountType>,
    pub end_date: Option<String>,
    pub payment_schedule: Option<MandatePixPaymentSchedule>,
    pub reference: Option<String>,
    pub start_date: Option<String>,
}

Fields

amount_includes_iof: Option<MandatePixAmountIncludesIof>

Determines if the amount includes the IOF tax.

amount_type: Option<MandatePixAmountType>

Type of amount.

end_date: Option<String>

Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD.

payment_schedule: Option<MandatePixPaymentSchedule>

Schedule at which the future payments will be charged.

reference: Option<String>

Subscription name displayed to buyers in their bank app.

start_date: Option<String>

Start date of the mandate, in YYYY-MM-DD.