pub struct PaymentData {
pub description: Option<String>,
pub metadata: Option<HashMap<String, String>>,
}Fields
description: Option<String>An arbitrary string attached to the destination payment. Often useful for displaying to users.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.