pub struct PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode {
pub hosted_instructions_url: String,
pub mobile_auth_url: String,
pub qr_code: PaymentIntentNextActionCashappQrCode,
}Fields
hosted_instructions_url: StringThe URL to the hosted Cash App Pay instructions page, which allows customers to view the QR code, and supports QR code refreshing on expiration.
mobile_auth_url: StringThe url for mobile redirect based auth
qr_code: PaymentIntentNextActionCashappQrCodeTrait Implementations
Sourceimpl Clone for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
impl Clone for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
Sourcefn clone(&self) -> PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
fn clone(&self) -> PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl FromValueOpt for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
impl FromValueOpt for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
fn from_value(v: Value) -> Option<Self>
Sourceimpl PartialEq for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
impl PartialEq for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
Sourcefn eq(
&self,
other: &PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode,
) -> bool
fn eq( &self, other: &PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode
impl StructuralPartialEq for PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode