PaymentIntentNextActionPixDisplayQrCode

Struct PaymentIntentNextActionPixDisplayQrCode 

pub struct PaymentIntentNextActionPixDisplayQrCode {
    pub data: Option<String>,
    pub expires_at: Option<i64>,
    pub hosted_instructions_url: Option<String>,
    pub image_url_png: Option<String>,
    pub image_url_svg: Option<String>,
}

Fields

data: Option<String>

The raw data string used to generate QR code, it should be used together with QR code library.

expires_at: Option<i64>

The date (unix timestamp) when the PIX expires.

hosted_instructions_url: Option<String>

The URL to the hosted pix instructions page, which allows customers to view the pix QR code.

image_url_png: Option<String>

The image_url_png string used to render png QR code

image_url_svg: Option<String>

The image_url_svg string used to render svg QR code