pub struct PaymentMethodAcssDebit {
pub bank_name: Option<String>,
pub fingerprint: Option<String>,
pub institution_number: Option<String>,
pub last4: Option<String>,
pub transit_number: Option<String>,
}Fields
bank_name: Option<String>Name of the bank associated with the bank account.
fingerprint: Option<String>Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
institution_number: Option<String>Institution number of the bank account.
last4: Option<String>Last four digits of the bank account number.
transit_number: Option<String>Transit number of the bank account.