pub struct PaymentMethodCardWalletVisaCheckout {
pub billing_address: Option<Address>,
pub email: Option<String>,
pub name: Option<String>,
pub shipping_address: Option<Address>,
}Fields
billing_address: Option<Address>Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
email: Option<String>Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
name: Option<String>Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
shipping_address: Option<Address>Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.