pub struct PaymentMethodDetailsAlipay {
pub buyer_id: Option<String>,
pub fingerprint: Option<String>,
pub transaction_id: Option<String>,
}Fields
buyer_id: Option<String>Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same.
fingerprint: Option<String>Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same.
transaction_id: Option<String>Transaction ID of this particular Alipay transaction.