PaymentMethodDetailsCardNetworkToken

Struct PaymentMethodDetailsCardNetworkToken 

pub struct PaymentMethodDetailsCardNetworkToken {
    pub used: bool,
}

Fields

used: bool

Indicates if Stripe used a network token, either user provided or Stripe managed when processing the transaction.