PaymentMethodDetailsCardWallet

Struct PaymentMethodDetailsCardWallet 

pub struct PaymentMethodDetailsCardWallet {
    pub amex_express_checkout: Option<PaymentMethodDetailsCardWalletAmexExpressCheckout>,
    pub apple_pay: Option<PaymentMethodDetailsCardWalletApplePay>,
    pub dynamic_last4: Option<String>,
    pub google_pay: Option<PaymentMethodDetailsCardWalletGooglePay>,
    pub link: Option<PaymentMethodDetailsCardWalletLink>,
    pub masterpass: Option<PaymentMethodDetailsCardWalletMasterpass>,
    pub samsung_pay: Option<PaymentMethodDetailsCardWalletSamsungPay>,
    pub type_: PaymentMethodDetailsCardWalletType,
    pub visa_checkout: Option<PaymentMethodDetailsCardWalletVisaCheckout>,
}

Fields

amex_express_checkout: Option<PaymentMethodDetailsCardWalletAmexExpressCheckout>apple_pay: Option<PaymentMethodDetailsCardWalletApplePay>dynamic_last4: Option<String>

(For tokenized numbers only.) The last four digits of the device account number.

google_pay: Option<PaymentMethodDetailsCardWalletGooglePay>link: Option<PaymentMethodDetailsCardWalletLink>masterpass: Option<PaymentMethodDetailsCardWalletMasterpass>samsung_pay: Option<PaymentMethodDetailsCardWalletSamsungPay>type_: PaymentMethodDetailsCardWalletType

The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.

visa_checkout: Option<PaymentMethodDetailsCardWalletVisaCheckout>