PaymentMethodDetailsCrypto

Struct PaymentMethodDetailsCrypto 

pub struct PaymentMethodDetailsCrypto {
    pub buyer_address: Option<String>,
    pub network: Option<PaymentMethodDetailsCryptoNetwork>,
    pub token_currency: Option<PaymentMethodDetailsCryptoTokenCurrency>,
    pub transaction_hash: Option<String>,
}

Fields

buyer_address: Option<String>

The wallet address of the customer.

network: Option<PaymentMethodDetailsCryptoNetwork>

The blockchain network that the transaction was sent on.

token_currency: Option<PaymentMethodDetailsCryptoTokenCurrency>

The token currency that the transaction was sent with.

transaction_hash: Option<String>

The blockchain transaction hash of the crypto payment.