pub struct PaymentMethodDetailsPaymentRecordLink {
pub country: Option<String>,
}Fields
country: Option<String>Two-letter ISO code representing the funding source country beneath the Link payment. You could use this attribute to get a sense of international fees.