pub struct PaymentMethodDetailsPaymentRecordSepaDebit {
pub bank_code: Option<String>,
pub branch_code: Option<String>,
pub country: Option<String>,
pub expected_debit_date: Option<String>,
pub fingerprint: Option<String>,
pub last4: Option<String>,
pub mandate: Option<String>,
}Fields
bank_code: Option<String>Bank code of bank associated with the bank account.
branch_code: Option<String>Branch code of bank associated with the bank account.
country: Option<String>Two-letter ISO code representing the country the bank account is located in.
expected_debit_date: Option<String>Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
fingerprint: Option<String>Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
last4: Option<String>Last four characters of the IBAN.
mandate: Option<String>Find the ID of the mandate used for this payment under the payment_method_details.sepa_debit.mandate property on the Charge. Use this mandate ID to retrieve the Mandate.