PaymentMethodOptionsCardPresent

Struct PaymentMethodOptionsCardPresent 

pub struct PaymentMethodOptionsCardPresent {
    pub capture_method: Option<PaymentMethodOptionsCardPresentCaptureMethod>,
    pub request_extended_authorization: Option<bool>,
    pub request_incremental_authorization_support: Option<bool>,
    pub routing: Option<PaymentMethodOptionsCardPresentRouting>,
}

Fields

capture_method: Option<PaymentMethodOptionsCardPresentCaptureMethod>

Controls when the funds will be captured from the customer’s account.

request_extended_authorization: Option<bool>

Request ability to capture this payment beyond the standard authorization validity window.

request_incremental_authorization_support: Option<bool>

Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support.

routing: Option<PaymentMethodOptionsCardPresentRouting>