pub struct PaymentMethodOptionsCustomerBalance {
pub bank_transfer: Option<PaymentMethodOptionsCustomerBalanceBankTransfer>,
pub funding_type: Option<PaymentMethodOptionsCustomerBalanceFundingType>,
pub setup_future_usage: Option<PaymentMethodOptionsCustomerBalanceSetupFutureUsage>,
}Fields
bank_transfer: Option<PaymentMethodOptionsCustomerBalanceBankTransfer>funding_type: Option<PaymentMethodOptionsCustomerBalanceFundingType>The funding method type to be used when there are not enough funds in the customer balance.
Permitted values include: bank_transfer.
setup_future_usage: Option<PaymentMethodOptionsCustomerBalanceSetupFutureUsage>Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.