PaymentMethodOptionsCustomerBalanceBankTransfer

Struct PaymentMethodOptionsCustomerBalanceBankTransfer 

pub struct PaymentMethodOptionsCustomerBalanceBankTransfer {
    pub eu_bank_transfer: Option<PaymentMethodOptionsCustomerBalanceEuBankAccount>,
    pub requested_address_types: Option<Vec<PaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes>>,
    pub type_: Option<PaymentMethodOptionsCustomerBalanceBankTransferType>,
}

Fields

eu_bank_transfer: Option<PaymentMethodOptionsCustomerBalanceEuBankAccount>requested_address_types: Option<Vec<PaymentMethodOptionsCustomerBalanceBankTransferRequestedAddressTypes>>

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: sort_code, zengin, iban, or spei.

type_: Option<PaymentMethodOptionsCustomerBalanceBankTransferType>

The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include: eu_bank_transfer, gb_bank_transfer, jp_bank_transfer, mx_bank_transfer, or us_bank_transfer.