pub struct PaymentMethodOptionsMandateOptionsPix {
pub amount: Option<i64>,
pub amount_includes_iof: Option<PaymentMethodOptionsMandateOptionsPixAmountIncludesIof>,
pub amount_type: Option<PaymentMethodOptionsMandateOptionsPixAmountType>,
pub currency: Option<Currency>,
pub end_date: Option<String>,
pub payment_schedule: Option<PaymentMethodOptionsMandateOptionsPixPaymentSchedule>,
pub reference: Option<String>,
pub start_date: Option<String>,
}Fields
amount: Option<i64>Amount to be charged for future payments.
amount_includes_iof: Option<PaymentMethodOptionsMandateOptionsPixAmountIncludesIof>Determines if the amount includes the IOF tax.
amount_type: Option<PaymentMethodOptionsMandateOptionsPixAmountType>Type of amount.
currency: Option<Currency>Three-letter ISO currency code, in lowercase.
end_date: Option<String>Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD.
payment_schedule: Option<PaymentMethodOptionsMandateOptionsPixPaymentSchedule>Schedule at which the future payments will be charged.
reference: Option<String>Subscription name displayed to buyers in their bank app.
start_date: Option<String>Start date of the mandate, in YYYY-MM-DD.