pub struct PaymentMethodOptionsPix {
pub amount_includes_iof: Option<PaymentMethodOptionsPixAmountIncludesIof>,
pub expires_after_seconds: Option<i64>,
pub expires_at: Option<i64>,
pub mandate_options: Option<PaymentMethodOptionsMandateOptionsPix>,
pub setup_future_usage: Option<PaymentMethodOptionsPixSetupFutureUsage>,
}Fields
amount_includes_iof: Option<PaymentMethodOptionsPixAmountIncludesIof>Determines if the amount includes the IOF tax.
expires_after_seconds: Option<i64>The number of seconds (between 10 and 1209600) after which Pix payment will expire.
expires_at: Option<i64>The timestamp at which the Pix expires.
mandate_options: Option<PaymentMethodOptionsMandateOptionsPix>setup_future_usage: Option<PaymentMethodOptionsPixSetupFutureUsage>Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.