PaymentMethodUsBankAccount

Struct PaymentMethodUsBankAccount 

pub struct PaymentMethodUsBankAccount {
    pub account_holder_type: Option<PaymentMethodUsBankAccountAccountHolderType>,
    pub account_type: Option<PaymentMethodUsBankAccountAccountType>,
    pub bank_name: Option<String>,
    pub financial_connections_account: Option<String>,
    pub fingerprint: Option<String>,
    pub last4: Option<String>,
    pub networks: Option<UsBankAccountNetworks>,
    pub routing_number: Option<String>,
    pub status_details: Option<PaymentMethodUsBankAccountStatusDetails>,
}

Fields

account_holder_type: Option<PaymentMethodUsBankAccountAccountHolderType>

Account holder type: individual or company.

account_type: Option<PaymentMethodUsBankAccountAccountType>

Account type: checkings or savings. Defaults to checking if omitted.

bank_name: Option<String>

The name of the bank.

financial_connections_account: Option<String>

The ID of the Financial Connections Account used to create the payment method.

fingerprint: Option<String>

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.

last4: Option<String>

Last four digits of the bank account number.

networks: Option<UsBankAccountNetworks>

Contains information about US bank account networks that can be used.

routing_number: Option<String>

Routing number of the bank account.

status_details: Option<PaymentMethodUsBankAccountStatusDetails>

Contains information about the future reusability of this PaymentMethod.