PaymentPagesCheckoutSessionBusinessName

Struct PaymentPagesCheckoutSessionBusinessName 

pub struct PaymentPagesCheckoutSessionBusinessName {
    pub enabled: bool,
    pub optional: bool,
}

Fields

enabled: bool

Indicates whether business name collection is enabled for the session

optional: bool

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to false.