PaymentPagesCheckoutSessionConsent

Struct PaymentPagesCheckoutSessionConsent 

pub struct PaymentPagesCheckoutSessionConsent {
    pub promotions: Option<PaymentPagesCheckoutSessionConsentPromotions>,
    pub terms_of_service: Option<PaymentPagesCheckoutSessionConsentTermsOfService>,
}

Fields

promotions: Option<PaymentPagesCheckoutSessionConsentPromotions>

If opt_in, the customer consents to receiving promotional communications from the merchant about this Checkout Session.

terms_of_service: Option<PaymentPagesCheckoutSessionConsentTermsOfService>

If accepted, the customer in this Checkout Session has agreed to the merchant’s terms of service.