PaymentPagesCheckoutSessionCustomFields

Struct PaymentPagesCheckoutSessionCustomFields 

pub struct PaymentPagesCheckoutSessionCustomFields {
    pub dropdown: Option<PaymentPagesCheckoutSessionCustomFieldsDropdown>,
    pub key: String,
    pub label: PaymentPagesCheckoutSessionCustomFieldsLabel,
    pub numeric: Option<PaymentPagesCheckoutSessionCustomFieldsNumeric>,
    pub optional: bool,
    pub text: Option<PaymentPagesCheckoutSessionCustomFieldsText>,
    pub type_: PaymentPagesCheckoutSessionCustomFieldsType,
}

Fields

dropdown: Option<PaymentPagesCheckoutSessionCustomFieldsDropdown>key: String

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.

label: PaymentPagesCheckoutSessionCustomFieldsLabelnumeric: Option<PaymentPagesCheckoutSessionCustomFieldsNumeric>optional: bool

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to false.

text: Option<PaymentPagesCheckoutSessionCustomFieldsText>type_: PaymentPagesCheckoutSessionCustomFieldsType

The type of the field.