PaymentPagesCheckoutSessionCustomText

Struct PaymentPagesCheckoutSessionCustomText 

pub struct PaymentPagesCheckoutSessionCustomText {
    pub after_submit: Option<PaymentPagesCheckoutSessionCustomTextPosition>,
    pub shipping_address: Option<PaymentPagesCheckoutSessionCustomTextPosition>,
    pub submit: Option<PaymentPagesCheckoutSessionCustomTextPosition>,
    pub terms_of_service_acceptance: Option<PaymentPagesCheckoutSessionCustomTextPosition>,
}

Fields

after_submit: Option<PaymentPagesCheckoutSessionCustomTextPosition>

Custom text that should be displayed after the payment confirmation button.

shipping_address: Option<PaymentPagesCheckoutSessionCustomTextPosition>

Custom text that should be displayed alongside shipping address collection.

submit: Option<PaymentPagesCheckoutSessionCustomTextPosition>

Custom text that should be displayed alongside the payment confirmation button.

terms_of_service_acceptance: Option<PaymentPagesCheckoutSessionCustomTextPosition>

Custom text that should be displayed in place of the default terms of service agreement text.