PlanTier

Struct PlanTier 

pub struct PlanTier {
    pub flat_amount: Option<i64>,
    pub flat_amount_decimal: Option<String>,
    pub unit_amount: Option<i64>,
    pub unit_amount_decimal: Option<String>,
    pub up_to: Option<i64>,
}

Fields

flat_amount: Option<i64>

Price for the entire tier.

flat_amount_decimal: Option<String>

Same as flat_amount, but contains a decimal value with at most 12 decimal places.

unit_amount: Option<i64>

Per unit price for units relevant to the tier.

unit_amount_decimal: Option<String>

Same as unit_amount, but contains a decimal value with at most 12 decimal places.

up_to: Option<i64>

Up to and including to this quantity will be contained in the tier.