pub struct PromotionCodesResourceRestrictions {
pub currency_options: Option<HashMap<Currency, PromotionCodeCurrencyOption>>,
pub first_time_transaction: bool,
pub minimum_amount: Option<i64>,
pub minimum_amount_currency: Option<Currency>,
}Fields
currency_options: Option<HashMap<Currency, PromotionCodeCurrencyOption>>Promotion code restrictions defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
first_time_transaction: boolA Boolean indicating if the Promotion Code should only be redeemed for Customers without any successful payments or invoices.
minimum_amount: Option<i64>Minimum amount required to redeem this Promotion Code into a Coupon (e.g., a purchase must be $100 or more to work).
minimum_amount_currency: Option<Currency>Three-letter ISO code for minimum_amount