Recurring

Struct Recurring 

pub struct Recurring {
    pub interval: RecurringInterval,
    pub interval_count: u64,
    pub meter: Option<String>,
    pub trial_period_days: Option<u32>,
    pub usage_type: RecurringUsageType,
}

Fields

interval: RecurringInterval

The frequency at which a subscription is billed. One of day, week, month or year.

interval_count: u64

The number of intervals (specified in the interval attribute) between subscription billings. For example, interval=month and interval_count=3 bills every 3 months.

meter: Option<String>

The meter tracking the usage of a metered price

trial_period_days: Option<u32>

Default number of trial days when subscribing a customer to this price using trial_from_plan=true.

usage_type: RecurringUsageType

Configures how the quantity per period should be determined. Can be either metered or licensed. licensed automatically bills the quantity set when adding it to a subscription. metered aggregates the total usage based on usage records. Defaults to licensed.