SetupAttemptPaymentMethodDetailsCardWallet

Struct SetupAttemptPaymentMethodDetailsCardWallet 

pub struct SetupAttemptPaymentMethodDetailsCardWallet {
    pub apple_pay: Option<PaymentMethodDetailsCardWalletApplePay>,
    pub google_pay: Option<PaymentMethodDetailsCardWalletGooglePay>,
    pub type_: SetupAttemptPaymentMethodDetailsCardWalletType,
}

Fields

apple_pay: Option<PaymentMethodDetailsCardWalletApplePay>google_pay: Option<PaymentMethodDetailsCardWalletGooglePay>type_: SetupAttemptPaymentMethodDetailsCardWalletType

The type of the card wallet, one of apple_pay, google_pay, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.