pub struct SetupIntentNextActionRedirectToUrl {
pub return_url: Option<String>,
pub url: Option<String>,
}Fields
return_url: Option<String>If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion.
url: Option<String>The URL you must redirect your customer to in order to authenticate.