SourceCodeVerificationFlow

Struct SourceCodeVerificationFlow 

pub struct SourceCodeVerificationFlow {
    pub attempts_remaining: i64,
    pub status: String,
}

Fields

attempts_remaining: i64

The number of attempts remaining to authenticate the source object with a verification code.

status: String

The status of the code verification, either pending (awaiting verification, attempts_remaining should be greater than 0), succeeded (successful verification) or failed (failed verification, cannot be verified anymore as attempts_remaining should be 0).