pub struct SourceOwner {
pub address: Option<Address>,
pub email: Option<String>,
pub name: Option<String>,
pub phone: Option<String>,
pub verified_address: Option<Address>,
pub verified_email: Option<String>,
pub verified_name: Option<String>,
pub verified_phone: Option<String>,
}Fields
address: Option<Address>Owner’s address.
email: Option<String>Owner’s email address.
name: Option<String>Owner’s full name.
phone: Option<String>Owner’s phone number (including extension).
verified_address: Option<Address>Verified owner’s address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
verified_email: Option<String>Verified owner’s email address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
verified_name: Option<String>Verified owner’s full name. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
verified_phone: Option<String>Verified owner’s phone number (including extension). Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.