pub struct StackableDiscountWithDiscountSettings {
pub coupon: Option<Expandable<Coupon>>,
pub discount: Option<Expandable<Discount>>,
pub promotion_code: Option<Expandable<PromotionCode>>,
}Fields
coupon: Option<Expandable<Coupon>>ID of the coupon to create a new discount for.
discount: Option<Expandable<Discount>>ID of an existing discount on the object (or one of its ancestors) to reuse.
promotion_code: Option<Expandable<PromotionCode>>ID of the promotion code to create a new discount for.