SubscriptionPaymentMethodOptionsMandateOptionsPix

Struct SubscriptionPaymentMethodOptionsMandateOptionsPix 

pub struct SubscriptionPaymentMethodOptionsMandateOptionsPix {
    pub amount: Option<i64>,
    pub amount_includes_iof: Option<SubscriptionPaymentMethodOptionsMandateOptionsPixAmountIncludesIof>,
    pub end_date: Option<String>,
    pub payment_schedule: Option<SubscriptionPaymentMethodOptionsMandateOptionsPixPaymentSchedule>,
}

Fields

amount: Option<i64>

Amount to be charged for future payments.

amount_includes_iof: Option<SubscriptionPaymentMethodOptionsMandateOptionsPixAmountIncludesIof>

Determines if the amount includes the IOF tax.

end_date: Option<String>

Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD.

payment_schedule: Option<SubscriptionPaymentMethodOptionsMandateOptionsPixPaymentSchedule>

Schedule at which the future payments will be charged.