SubscriptionScheduleCurrentPhase

Struct SubscriptionScheduleCurrentPhase 

pub struct SubscriptionScheduleCurrentPhase {
    pub end_date: Timestamp,
    pub start_date: Timestamp,
}

Fields

end_date: Timestamp

The end of this phase of the subscription schedule.

start_date: Timestamp

The start of this phase of the subscription schedule.