pub struct SubscriptionsResourceBillingSchedulesAppliesTo {
pub price: Option<Expandable<Price>>,
pub type_: SubscriptionsResourceBillingSchedulesAppliesToType,
}Expand description
Represents the entities that the billing schedule applies to.
Fields
price: Option<Expandable<Price>>The billing schedule will apply to the subscription item with the given price ID.
type_: SubscriptionsResourceBillingSchedulesAppliesToTypeControls which subscription items the billing schedule applies to.