pub struct SubscriptionsResourceBillingSchedulesBillUntil {
pub computed_timestamp: Timestamp,
pub duration: Option<SubscriptionsResourceBillingSchedulesBillUntilDuration>,
pub timestamp: Option<Timestamp>,
pub type_: SubscriptionsResourceBillingSchedulesBillUntilType,
}Expand description
Specifies the end of billing period.
Fields
computed_timestamp: TimestampThe timestamp the billing schedule will apply until.
duration: Option<SubscriptionsResourceBillingSchedulesBillUntilDuration>Specifies the billing period.
timestamp: Option<Timestamp>If specified, the billing schedule will apply until the specified timestamp.
type_: SubscriptionsResourceBillingSchedulesBillUntilTypeDescribes how the billing schedule will determine the end date. Either duration or timestamp.