SubscriptionsResourcePaymentMethodOptions

Struct SubscriptionsResourcePaymentMethodOptions 

pub struct SubscriptionsResourcePaymentMethodOptions {
    pub acss_debit: Option<InvoicePaymentMethodOptionsAcssDebit>,
    pub bancontact: Option<InvoicePaymentMethodOptionsBancontact>,
    pub card: Option<SubscriptionPaymentMethodOptionsCard>,
    pub customer_balance: Option<InvoicePaymentMethodOptionsCustomerBalance>,
    pub konbini: Option<InvoicePaymentMethodOptionsKonbini>,
    pub payto: Option<InvoicePaymentMethodOptionsPayto>,
    pub pix: Option<SubscriptionPaymentMethodOptionsPix>,
    pub sepa_debit: Option<InvoicePaymentMethodOptionsSepaDebit>,
    pub upi: Option<InvoicePaymentMethodOptionsUpi>,
    pub us_bank_account: Option<InvoicePaymentMethodOptionsUsBankAccount>,
}

Fields

acss_debit: Option<InvoicePaymentMethodOptionsAcssDebit>

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to invoices created by the subscription.

bancontact: Option<InvoicePaymentMethodOptionsBancontact>

This sub-hash contains details about the Bancontact payment method options to pass to invoices created by the subscription.

card: Option<SubscriptionPaymentMethodOptionsCard>

This sub-hash contains details about the Card payment method options to pass to invoices created by the subscription.

customer_balance: Option<InvoicePaymentMethodOptionsCustomerBalance>

This sub-hash contains details about the Bank transfer payment method options to pass to invoices created by the subscription.

konbini: Option<InvoicePaymentMethodOptionsKonbini>

This sub-hash contains details about the Konbini payment method options to pass to invoices created by the subscription.

payto: Option<InvoicePaymentMethodOptionsPayto>

This sub-hash contains details about the PayTo payment method options to pass to invoices created by the subscription.

pix: Option<SubscriptionPaymentMethodOptionsPix>

This sub-hash contains details about the Pix payment method options to pass to invoices created by the subscription.

sepa_debit: Option<InvoicePaymentMethodOptionsSepaDebit>

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to invoices created by the subscription.

upi: Option<InvoicePaymentMethodOptionsUpi>

This sub-hash contains details about the UPI payment method options to pass to invoices created by the subscription.

us_bank_account: Option<InvoicePaymentMethodOptionsUsBankAccount>

This sub-hash contains details about the ACH direct debit payment method options to pass to invoices created by the subscription.