pub struct SubscriptionsResourcePendingUpdate {
pub billing_cycle_anchor: Option<Timestamp>,
pub discount: Option<Discount>,
pub discounts: Option<Vec<Expandable<Discount>>>,
pub expires_at: Timestamp,
pub metadata: Option<HashMap<String, String>>,
pub subscription_items: Option<Vec<SubscriptionItem>>,
pub trial_end: Option<Timestamp>,
pub trial_from_plan: Option<bool>,
}Expand description
Pending Updates store the changes pending from a previous update that will be applied to the Subscription upon successful payment.
Fields
billing_cycle_anchor: Option<Timestamp>If the update is applied, determines the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices.
The timestamp is in UTC format.
discount: Option<Discount>The pending subscription-level discount that will be applied when the pending update is applied.
discounts: Option<Vec<Expandable<Discount>>>The discounts that will be applied to the subscription when the pending update is applied.
Use expand[]=discounts to expand each discount.
expires_at: TimestampThe point after which the changes reflected by this update will be discarded and no longer applied.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
subscription_items: Option<Vec<SubscriptionItem>>List of subscription items, each with an attached plan, that will be set if the update is applied.
trial_end: Option<Timestamp>Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
trial_from_plan: Option<bool>Indicates if a plan’s trial_period_days should be applied to the subscription.
Setting trial_end per subscription is preferred, and this defaults to false.
Setting this flag to true together with trial_end is not allowed.
See Using trial periods on subscriptions to learn more.