SubscriptionsResourceTrialSettingsEndBehavior

Struct SubscriptionsResourceTrialSettingsEndBehavior 

pub struct SubscriptionsResourceTrialSettingsEndBehavior {
    pub missing_payment_method: SubscriptionsResourceTrialSettingsEndBehaviorMissingPaymentMethod,
}
Defines how a subscription behaves when a trial ends.

Fields

missing_payment_method: SubscriptionsResourceTrialSettingsEndBehaviorMissingPaymentMethod

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.