TaxCode

Struct TaxCode 

pub struct TaxCode {
    pub description: String,
    pub id: TaxCodeId,
    pub name: String,
}
Tax codes classify goods and services for tax purposes.

For more details see <https://stripe.com/docs/api/tax_codes/object>.

Fields

description: String

A detailed description of which types of products the tax code represents.

id: TaxCodeId

Unique identifier for the object.

name: String

A short name for the tax code.