pub struct TestHelpersTestClock {
pub created: Timestamp,
pub deletes_after: Timestamp,
pub frozen_time: Timestamp,
pub id: TestHelpersTestClockId,
pub livemode: bool,
pub name: Option<String>,
pub status: TestHelpersTestClockStatus,
pub status_details: BillingClocksResourceStatusDetailsStatusDetails,
}Expand description
A test clock enables deterministic control over objects in testmode. With a test clock, you can create. objects at a frozen time in the past or future, and advance to a specific future time to observe webhooks and state changes. After the clock advances,. you can either validate the current state of your scenario (and test your assumptions), change the current state of your scenario (and test more complex scenarios), or keep advancing forward in time.
Fields
created: TimestampTime at which the object was created. Measured in seconds since the Unix epoch.
deletes_after: TimestampTime at which this clock is scheduled to auto delete.
frozen_time: TimestampTime at which all objects belonging to this clock are frozen.
id: TestHelpersTestClockIdUnique identifier for the object.
livemode: boolIf the object exists in live mode, the value is true.
If the object exists in test mode, the value is false.
name: Option<String>The custom name supplied at creation.
status: TestHelpersTestClockStatusThe status of the Test Clock.
status_details: BillingClocksResourceStatusDetailsStatusDetailsTrait Implementations
Sourceimpl Clone for TestHelpersTestClock
impl Clone for TestHelpersTestClock
Sourcefn clone(&self) -> TestHelpersTestClock
fn clone(&self) -> TestHelpersTestClock
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TestHelpersTestClock
impl Debug for TestHelpersTestClock
Sourceimpl Deserialize for TestHelpersTestClock
impl Deserialize for TestHelpersTestClock
Sourceimpl FromValueOpt for TestHelpersTestClock
impl FromValueOpt for TestHelpersTestClock
fn from_value(v: Value) -> Option<Self>
Sourceimpl Object for TestHelpersTestClock
impl Object for TestHelpersTestClock
Sourceimpl PartialEq for TestHelpersTestClock
impl PartialEq for TestHelpersTestClock
Sourcefn eq(&self, other: &TestHelpersTestClock) -> bool
fn eq(&self, other: &TestHelpersTestClock) -> bool
self and other values to be equal, and is used by ==.