pub struct TransferData {
pub amount: Option<i64>,
pub description: Option<String>,
pub destination: Expandable<Account>,
pub metadata: Option<HashMap<String, String>>,
pub payment_data: Option<PaymentData>,
}Fields
amount: Option<i64>The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the amount, and must be a positive integer. representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
description: Option<String>An arbitrary string attached to the transfer. Often useful for displaying to users.
destination: Expandable<Account>The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
metadata: Option<HashMap<String, String>>Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
payment_data: Option<PaymentData>Trait Implementations
Sourceimpl Clone for TransferData
impl Clone for TransferData
Sourcefn clone(&self) -> TransferData
fn clone(&self) -> TransferData
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more