pub struct CardIssuingAccountTermsOfService {
pub date: Option<Timestamp>,
pub ip: Option<String>,
pub user_agent: Option<String>,
}Fields
date: Option<Timestamp>The Unix timestamp marking when the account representative accepted the service agreement.
ip: Option<String>The IP address from which the account representative accepted the service agreement.
user_agent: Option<String>The user agent of the browser from which the account representative accepted the service agreement.