pub struct InvoiceItemThresholdReason {
pub line_item_ids: Vec<String>,
pub usage_gte: i64,
}Fields
line_item_ids: Vec<String>The IDs of the line items that triggered the threshold invoice.
usage_gte: i64The quantity threshold boundary that applied to the given line item.