IssuingAuthorizationFraudChallenge

Struct IssuingAuthorizationFraudChallenge 

pub struct IssuingAuthorizationFraudChallenge {
    pub channel: IssuingAuthorizationFraudChallengeChannel,
    pub status: IssuingAuthorizationFraudChallengeStatus,
    pub undeliverable_reason: Option<IssuingAuthorizationFraudChallengeUndeliverableReason>,
}

Fields

channel: IssuingAuthorizationFraudChallengeChannel

The method by which the fraud challenge was delivered to the cardholder.

status: IssuingAuthorizationFraudChallengeStatus

The status of the fraud challenge.

undeliverable_reason: Option<IssuingAuthorizationFraudChallengeUndeliverableReason>

If the challenge is not deliverable, the reason why.