IssuingAuthorizationFuelData

Struct IssuingAuthorizationFuelData 

pub struct IssuingAuthorizationFuelData {
    pub industry_product_code: Option<String>,
    pub quantity_decimal: Option<String>,
    pub type_: Option<IssuingAuthorizationFuelDataType>,
    pub unit: Option<IssuingAuthorizationFuelDataUnit>,
    pub unit_cost_decimal: Option<String>,
}

Fields

industry_product_code: Option<String>

Conexxus Payment System Product Code identifying the primary fuel product purchased.

quantity_decimal: Option<String>

The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.

type_: Option<IssuingAuthorizationFuelDataType>

The type of fuel that was purchased.

unit: Option<IssuingAuthorizationFuelDataUnit>

The units for quantity_decimal.

unit_cost_decimal: Option<String>

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.