pub struct IssuingAuthorizationPendingRequest {
pub amount: i64,
pub amount_details: Option<IssuingAuthorizationAmountDetails>,
pub currency: Currency,
pub is_amount_controllable: bool,
pub merchant_amount: i64,
pub merchant_currency: Currency,
pub network_risk_score: Option<i64>,
}Fields
amount: i64The additional amount Stripe will hold if the authorization is approved, in the card’s currency and in the smallest currency unit.
amount_details: Option<IssuingAuthorizationAmountDetails>Detailed breakdown of amount components.
These amounts are denominated in currency and in the smallest currency unit.
currency: CurrencyThree-letter ISO currency code, in lowercase. Must be a supported currency.
is_amount_controllable: boolIf set true, you may provide amount to control how much to hold for the authorization.
merchant_amount: i64The amount the merchant is requesting to be authorized in the merchant_currency.
The amount is in the smallest currency unit.
merchant_currency: CurrencyThe local currency the merchant is requesting to authorize.
network_risk_score: Option<i64>The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.