IssuingAuthorizationVerificationData

Struct IssuingAuthorizationVerificationData 

pub struct IssuingAuthorizationVerificationData {
    pub address_line1_check: IssuingAuthorizationVerificationDataAddressLine1Check,
    pub address_postal_code_check: IssuingAuthorizationVerificationDataAddressPostalCodeCheck,
    pub authentication_exemption: Option<IssuingAuthorizationAuthenticationExemption>,
    pub cvc_check: IssuingAuthorizationVerificationDataCvcCheck,
    pub expiry_check: IssuingAuthorizationVerificationDataExpiryCheck,
    pub postal_code: Option<String>,
    pub three_d_secure: Option<IssuingAuthorizationThreeDSecure>,
}

Fields

address_line1_check: IssuingAuthorizationVerificationDataAddressLine1Check

Whether the cardholder provided an address first line and if it matched the cardholder’s billing.address.line1.

address_postal_code_check: IssuingAuthorizationVerificationDataAddressPostalCodeCheck

Whether the cardholder provided a postal code and if it matched the cardholder’s billing.address.postal_code.

authentication_exemption: Option<IssuingAuthorizationAuthenticationExemption>

The exemption applied to this authorization.

cvc_check: IssuingAuthorizationVerificationDataCvcCheck

Whether the cardholder provided a CVC and if it matched Stripe’s record.

expiry_check: IssuingAuthorizationVerificationDataExpiryCheck

Whether the cardholder provided an expiry date and if it matched Stripe’s record.

postal_code: Option<String>

The postal code submitted as part of the authorization used for postal code verification.

three_d_secure: Option<IssuingAuthorizationThreeDSecure>

3D Secure details.