pub struct IssuingCardholderSpendingLimit {
pub amount: i64,
pub categories: Option<Vec<IssuingCardholderSpendingLimitCategories>>,
pub interval: IssuingCardholderSpendingLimitInterval,
}Fields
amount: i64Maximum amount allowed to spend per interval. This amount is in the card’s currency and in the smallest currency unit.
categories: Option<Vec<IssuingCardholderSpendingLimitCategories>>Array of strings containing categories this limit applies to. Omitting this field will apply the limit to all categories.
interval: IssuingCardholderSpendingLimitIntervalInterval (or event) to which the amount applies.