pub struct IssuingNetworkTokenAddress {
pub line1: String,
pub postal_code: String,
}Fields
line1: StringThe street address of the cardholder tokenizing the card.
postal_code: StringThe postal code of the cardholder tokenizing the card.