pub struct IssuingPhysicalBundle {
pub features: IssuingPhysicalBundleFeatures,
pub id: IssuingPhysicalBundleId,
pub livemode: bool,
pub name: String,
pub status: IssuingPhysicalBundleStatus,
pub type_: IssuingPhysicalBundleType,
}Expand description
A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.
Fields
features: IssuingPhysicalBundleFeaturesid: IssuingPhysicalBundleIdUnique identifier for the object.
livemode: boolIf the object exists in live mode, the value is true.
If the object exists in test mode, the value is false.
name: StringFriendly display name.
status: IssuingPhysicalBundleStatusWhether this physical bundle can be used to create cards.
type_: IssuingPhysicalBundleTypeWhether this physical bundle is a standard Stripe offering or custom-made for you.