pub struct PaymentLinksResourceCustomText {
pub after_submit: Option<PaymentLinksResourceCustomTextPosition>,
pub shipping_address: Option<PaymentLinksResourceCustomTextPosition>,
pub submit: Option<PaymentLinksResourceCustomTextPosition>,
pub terms_of_service_acceptance: Option<PaymentLinksResourceCustomTextPosition>,
}Fields
after_submit: Option<PaymentLinksResourceCustomTextPosition>Custom text that should be displayed after the payment confirmation button.
shipping_address: Option<PaymentLinksResourceCustomTextPosition>Custom text that should be displayed alongside shipping address collection.
submit: Option<PaymentLinksResourceCustomTextPosition>Custom text that should be displayed alongside the payment confirmation button.
terms_of_service_acceptance: Option<PaymentLinksResourceCustomTextPosition>Custom text that should be displayed in place of the default terms of service agreement text.