pub struct PaymentMethodCardChecks {
pub address_line1_check: Option<String>,
pub address_postal_code_check: Option<String>,
pub cvc_check: Option<String>,
}Fields
address_line1_check: Option<String>If a address line1 was provided, results of the check, one of pass, fail, unavailable, or unchecked.
address_postal_code_check: Option<String>If a address postal code was provided, results of the check, one of pass, fail, unavailable, or unchecked.
cvc_check: Option<String>If a CVC was provided, results of the check, one of pass, fail, unavailable, or unchecked.