pub struct PaymentPagesCheckoutSessionBusinessName {
pub enabled: bool,
pub optional: bool,
}Fields
enabled: boolIndicates whether business name collection is enabled for the session
optional: boolWhether the customer is required to complete the field before completing the Checkout Session.
Defaults to false.