pub struct PaymentPagesCheckoutSessionCurrencyConversion {
pub amount_subtotal: i64,
pub amount_total: i64,
pub fx_rate: String,
pub source_currency: Currency,
}Fields
amount_subtotal: i64Total of all items in source currency before discounts or taxes are applied.
amount_total: i64Total of all items in source currency after discounts and taxes are applied.
fx_rate: StringExchange rate used to convert source currency amounts to customer currency amounts
source_currency: CurrencyCreation currency of the CheckoutSession before localization