pub struct SetupIntentNextActionVerifyWithMicrodeposits {
pub arrival_date: Timestamp,
pub hosted_verification_url: String,
pub microdeposit_type: Option<SetupIntentNextActionVerifyWithMicrodepositsMicrodepositType>,
}Fields
arrival_date: TimestampThe timestamp when the microdeposits are expected to land.
hosted_verification_url: StringThe URL for the hosted verification page, which allows customers to verify their bank account.
microdeposit_type: Option<SetupIntentNextActionVerifyWithMicrodepositsMicrodepositType>The type of the microdeposit sent to the customer. Used to distinguish between different verification methods.