SourceTransaction

Struct SourceTransaction 

pub struct SourceTransaction {
Show 13 fields pub ach_credit_transfer: Option<SourceTransactionAchCreditTransferData>, pub amount: i64, pub chf_credit_transfer: Option<SourceTransactionChfCreditTransferData>, pub created: Timestamp, pub currency: Currency, pub gbp_credit_transfer: Option<SourceTransactionGbpCreditTransferData>, pub id: SourceTransactionId, pub livemode: bool, pub paper_check: Option<SourceTransactionPaperCheckData>, pub sepa_credit_transfer: Option<SourceTransactionSepaCreditTransferData>, pub source: String, pub status: String, pub type_: SourceTransactionType,
}
Some payment methods have no required amount that a customer must send. Customers can be instructed to send any amount, and it can be made up of multiple transactions. As such, sources can have multiple associated transactions.

Fields

ach_credit_transfer: Option<SourceTransactionAchCreditTransferData>amount: i64

A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the amount your customer has pushed to the receiver.

chf_credit_transfer: Option<SourceTransactionChfCreditTransferData>created: Timestamp

Time at which the object was created. Measured in seconds since the Unix epoch.

currency: Currency

Three-letter ISO currency code, in lowercase. Must be a supported currency.

gbp_credit_transfer: Option<SourceTransactionGbpCreditTransferData>id: SourceTransactionId

Unique identifier for the object.

livemode: bool

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.

paper_check: Option<SourceTransactionPaperCheckData>sepa_credit_transfer: Option<SourceTransactionSepaCreditTransferData>source: String

The ID of the source this transaction is attached to.

status: String

The status of the transaction, one of succeeded, pending, or failed.

type_: SourceTransactionType

The type of source this transaction is attached to.