pub struct SourceTransactionGbpCreditTransferData {
pub fingerprint: Option<String>,
pub funding_method: Option<String>,
pub last4: Option<String>,
pub reference: Option<String>,
pub sender_account_number: Option<String>,
pub sender_name: Option<String>,
pub sender_sort_code: Option<String>,
}Fields
fingerprint: Option<String>Bank account fingerprint associated with the Stripe owned bank account receiving the transfer.
funding_method: Option<String>The credit transfer rails the sender used to push this transfer. The possible rails are: Faster Payments, BACS, CHAPS, and wire transfers. Currently only Faster Payments is supported.
last4: Option<String>Last 4 digits of sender account number associated with the transfer.
reference: Option<String>Sender entered arbitrary information about the transfer.
sender_account_number: Option<String>Sender account number associated with the transfer.
sender_name: Option<String>Sender name associated with the transfer.
sender_sort_code: Option<String>Sender sort code associated with the transfer.